Preprocessing
-------------


Covid 19
^^^^^^^^

Module for adapting to Covid 19 Kaggle challenge

.. automodule:: sisu.preprocessing.covid19
    :members:

Language
^^^^^^^^

Module for automatic language detection

.. automodule:: sisu.preprocessing.language
    :members:

Tokenizer
^^^^^^^^^

Module for decomposing text into base units


.. automodule:: sisu.preprocessing.tokenizer
    :members:

sentences
^^^^^^^^^

Module for extracting sentences


.. automodule:: sisu.preprocessing.sentences
    :members:
